from django.test import TestCase

from . import models


class RecipeTestCase(TestCase):
    def setUp(self):
        models.Recipe.objects.create(title="Pasta al pomodoro", description="Pasta al pomodoro, ricetta originale della nonna con salsa segreta")

    def test_field_name(self):
        """Recipe description is correctly extract"""
        pasta = models.Recipe.objects.get(title="Pasta al pomodoro")
        self.assertEqual(pasta.descrivi(), 'Pasta al pomodoro, ricetta originale della nonna con salsa segreta')



from rest_framework import routers

from . import views

urlpatterns = []

router = routers.SimpleRouter()

router.register(r'recipe', views.Recipe_View)
router.register(r'ingredient', views.Ingredient_View)

urlpatterns += router.urls


from django.db import models


class Recipe(models.Model):
    def __str__(self):
        return self.title
    
    def descrivi(self):
        return self.description

    title = models.CharField(max_length=100, unique=True)
    description = models.TextField()


class Ingredient(models.Model):

    def __str__(self):
        return self.title

    name = models.CharField(max_length=100)
    description = models.TextField(null=True, blank=True)
    recipes = models.ManyToManyField(Recipe)



from rest_framework import serializers

from . import models


class RecipeSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Recipe
        fields = ('title', 'description', )

class IngredientSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Recipe
        fields = ('name', 'description', )


# Generated by Django 4.1.2 on 2023-10-12 15:30

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Recipe',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100, unique=True)),
                ('description', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='Ingredient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True, null=True)),
                ('recipes', models.ManyToManyField(to='recipes_app.recipe')),
            ],
        ),
    ]
